Dijit Theme Tester

Loading themeTester ...
Enabled Item
Disabled Item
Cut
Copy
Paste
Enabled Submenu
Submenu Item One
Submenu Item Two
Deeper Submenu
Sub-sub-menu Item One
Sub-sub-menu Item Two
Disabled Submenu
Submenu Item One
Submenu Item Two
Different popup
Different popup
File
Log globals
Log widgets
Destroy All
Edit
Cut
Copy
Paste
Undo
View
Normal
Outline
Zoom
50%
75%
100%
150%
200%
Themes
Dialogs
slow loading
action bar
TextBox Padding
theme default
0px
1px
2px
3px
4px
5px
Help
Help Topics
About Dijit
Disabled
You should not see this
Click me!

## Tooltips

- rich text tooltip Embedded bold RICH text weirdness!
- anchor tooltip tooltip on anchor

| tooltip below I'm below! |
tooltip after I'm on the right! (or left on RTL systems) |  | tooltip before I'm on the left! (or right on RTL systems)
| tooltip above I'm above! |

## Dialogs

- slow loading modal dialog
- modal dialog w/action bar

Show Tooltip Dialog

User: |
Password: |

Selecting a color will change the background color of the page. Use this to test how tooltips and drop downs appear with different backgrounds.

## 3x4

## 7x10

This tab container uses slide controls when the tabs are too wide to fit beside each other. If you make the left column narrow enough, the slide controls should appear.
SubTab 1 SubTab 2

# I am tab 3, inlined.

# I am tab 4, inlined.

File
New
Open
Save
Save As...
Edit
Cut
Copy
Paste
View
Normal
Outline
Zoom
50%
75%
100%
150%
200%
Help
Help Topics
About Dijit
Disabled
You should not see this
Click me!

## Buttons

Buttons can do an action, display a menu, or both:

Enabled:

Disabled:

## CheckBox

unchecked checked disabled disabled and checked

## Radio Buttons

news talk weather (disabled)

## dijit.form.DateTextBox

Enabled w/placeHolder: Disabled w/placeHolder: Disabled w/value:

## dijit.form.TimeTextBox

Enabled: Disabled:

## dijit.form.CurrencyTextBox

Enabled: Disabled:

## dijit.form.NumberSpinner max=100

Enabled: Disabled:

## dijit.form.Select

Enabled:
Alabama Alaska Arizona Arkansas California New
Mexico
Disabled:
Alabama Alaska Arizona Arkansas California New
Mexico

## dijit.form.FilteringSelect

Enabled w/placeHolder: Disabled w/placeHolder: Disabled w/value:

## dijit.form.Textarea

Enabled:

This text area will expand and contract as you type ‪text.‬ Lorem ipsum dolor sit ‪amet,‬ consectetuer adipiscing elit, sed diam nonummy nibh euismod tincidunt ut laoreet dolore magna aliquam erat volutpat. Ut wisi enim ad minim veniam, quis nostrud exerci tation ullamcorper suscipit lobortis nisl ut aliquip ex ea commodo ‪consequat.‬

Disabled:

This text area is disabled and you shouldn't be able to type in ‪it.‬

## dijit.form.SimpleTextarea

Enabled:

This text area has a constant height and displays a scrollbar when ‪necessary.‬ Lorem ipsum dolor sit ‪amet,‬ consectetuer adipiscing elit, sed diam nonummy nibh euismod tincidunt ut laoreet dolore magna aliquam erat volutpat. Ut wisi enim ad minim veniam, quis nostrud exerci tation ullamcorper suscipit lobortis nisl ut aliquip ex ea commodo consequat. Duis autem vel eum iriure dolor in hendrerit in vulputate velit esse molestie ‪consequat,‬ vel illum dolore eu feugiat nulla facilisis at vero eros et accumsan et iusto odio dignissim qui blandit praesent luptatum zzril delenit augue duis dolore te feugait nulla ‪facilisi.‬

Disabled:

Lorem ipsum dolor sit ‪amet,‬ consectetuer adipiscing elit, sed diam nonummy nibh euismod tincidunt ut laoreet dolore magna aliquam erat volutpat. Ut wisi enim ad minim veniam, quis nostrud exerci tation ullamcorper suscipit lobortis nisl ut aliquip ex ea commodo consequat. Duis autem vel eum iriure dolor in hendrerit in vulputate velit esse molestie ‪consequat,‬ vel illum dolore eu feugiat nulla facilisis at vero eros et accumsan et iusto odio dignissim qui blandit praesent luptatum zzril delenit augue duis dolore te feugait nulla ‪facilisi.‬

Enabled:

- Lorem and a link, what do you think?
- This is the Editor with a Toolbar attached.

Disabled:

- Lorem and a link, what do you think?
- This is the Editor with a Toolbar attached.

## Enabled

1. 0
2. 100

Slider2 Value:

1. lowest
2. normal
3. highest

Value:

1. small
2. medium
3. large

## Disabled

1. 0
2. 100

1. lowest
2. normal
3. highest

1. small
2. medium
3. large

## TitlePane

This is a title pane. It can be expanded and collapsed.

Sed sollicitudin suscipit risus. Nam ullamcorper. Sed nisl lectus, pellentesque nec, malesuada eget, ornare a, libero. Lorem ipsum dolor sit amet, consectetuer adipiscing elit.

## ProgressBar

Indeterminate:

## dijit.InlineEditBox + dijit.form.TextBox on <h3>

(HTML before)

### Edit me - I trigger the onChange callback

(HTML after)

## dijit.InlineEditBox + dijit.form.Textarea

(HTML before)

I'm one big ‪paragraph.‬ Go ahead and edit ‪me.‬ I dare ‪you.‬ The quick brown fox jumped over the lazy ‪dog.‬ Blah blah blah blah blah blah ‪blah ...‬

(HTML after)

These links will disable / enable the text area above.

## dijit.form.DateTextBox

(HTML inline before) (HTML after)

## dijit.form.TimeTextBox

(HTML inline before) (HTML after)

## dijit.form.FilteringSelect + Inline + remote data store

(HTML inline before) Indiana (HTML after)

### Source 1

Item X
Item Y
Item Z

### Source 2

Item 1
Item 2
Item 3
This pane is closable, just for the icon ...

You can explore this single page after applying a Theme for use in creation of your own theme.

I am whole slew of Widgets on a page. Jump to dijit tests to test individual components.

There is a right-click [context] pop-up menu here, as well.

I am the last Tab

I am the second dialog. I am parented by the Low Tab Pane #3

Name: |
Location: |
Date: |